@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2025-05-05
+# Release 2025-04-23
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.8.0
+MAKERESOLVEDEB_VERSION=1.8.1
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -564,6 +564,7 @@ process_udev() {
     create_directory "${DEB_DIR}"/lib/udev/rules.d
     cat > "${DEB_DIR}"/lib/udev/rules.d/75-davincipanel.rules <<EOF
 SUBSYSTEM=="usb", ATTRS{idVendor}=="1edb", MODE="0666"
+KERNEL=="hidraw*", SUBSYSTEM=="hidraw", MODE="0777", GROUP="resolve"
 EOF
     cat > "${DEB_DIR}"/lib/udev/rules.d/75-davincikb.rules <<EOF
 SUBSYSTEMS=="usb", ENV{.LOCAL_ifNum}="\$attr{bInterfaceNumber}"
@@ -571,6 +572,11 @@ SUBSYSTEMS=="usb", ENV{.LOCAL_ifNum}="\$attr{bInterfaceNumber}"
 SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0b", ENV{.LOCAL_ifNum}=="04", MODE="0666"
 # Speed Editor Keyboard
 SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0e", ENV{.LOCAL_ifNum}=="02", MODE="0666"
+# Micro Color Panel
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0f", ENV{.LOCAL_ifNum}=="00", MODE="0666"
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0f", ENV{.LOCAL_ifNum}=="01", MODE="0666"
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0f", ENV{.LOCAL_ifNum}=="02", MODE="0666"
+SUBSYSTEM=="hidraw", KERNEL=="hidraw*", ATTRS{idVendor}=="1edb", ATTRS{idProduct}=="da0f", ENV{.LOCAL_ifNum}=="03", MODE="0666"
 EOF
     cat > "${DEB_DIR}"/lib/udev/rules.d/75-sdx.rules <<EOF
 SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
@@ -710,7 +716,6 @@ EOF
 }
 
 installer_extract_xorriso() {
-    # Extract archive
     check_command xorriso
     echo "Extracting archive"
     createf_directory "${UNPACK_DIR}"
@@ -724,7 +729,6 @@ installer_extract_xorriso() {
 }
 
 installer_extract_native() {
-    # Extract archive
     echo "Extracting archive"
     createf_directory "${UNPACK_DIR}"
     chmod a+x "${INSTALLER_ARCHIVE}"
@@ -910,9 +914,9 @@ case $RESOLVE_VERSION in
 	;;
     *)
 	echo "Unknown Resolve version"
-	echo "Trying Resolve 19 conversion process"
+	echo "Trying Resolve 20 conversion process"
 	installer_extract_native
-	process_19
+	process_20
 	process_braw
 	process_udev
 	process_desktop_shortcuts
@@ -923,13 +927,15 @@ esac
 close_deb
 
 if [[ -z "$CI_TEST" ]]; then
+    create_directory "./tmp"
     echo "Creating Debian package (This can take a while. Do not interrupt)"
-    if ! fakeroot dpkg-deb -b "${DEB_DIR}" "${DEB_DIR}".deb;
+    if ! TMPDIR=./tmp fakeroot dpkg-deb -b "${DEB_DIR}" "${DEB_DIR}".deb;
     then
 	ERRORS=$((ERRORS+1))
     fi
     
     # Clean up
+    remove_directory "./tmp"
     remove_directory "${UNPACK_DIR}"
     remove_directory "${DEB_DIR}"
 fi
